@@ -2,12 +2,12 @@ import platform
 
 
 VERSION_MAJOR = 0
-VERSION_MINOR = 7
+VERSION_MINOR = 9
 VERSION_RELEASE = 0
-VERSION_NUMBER = "0.7.0"
-VERSION = "0.7.0"
+VERSION_NUMBER = "0.9.0"
+VERSION = "0.9.0"
 
-REVISION = 12230
+REVISION = 13850
 
 HANDLE_INVALID = 0
 
@@ -17,6 +17,7 @@ INTERFACE_DEVICE = 0x0000000000000001
 INTERFACE_OSCILLOSCOPE = 0x0000000000000002
 INTERFACE_GENERATOR = 0x0000000000000004
 INTERFACE_I2CHOST = 0x0000000000000008
+INTERFACE_SERVER = 0x0000000000000010
 
 DEVICETYPE_OSCILLOSCOPE = 0x00000001
 DEVICETYPE_GENERATOR = 0x00000002
@@ -61,6 +62,12 @@ STATUS_NO_TRIGGER_ENABLED = -26
 STATUS_SYNCHRONIZATION_FAILED = -29
 STATUS_INVALID_HS56_COMBINED_DEVICE = -30
 STATUS_MEASUREMENT_RUNNING = -31
+STATUS_INITIALIZATION_ERROR_10001 = -10001
+STATUS_INITIALIZATION_ERROR_10002 = -10002
+STATUS_INITIALIZATION_ERROR_10003 = -10003
+STATUS_INITIALIZATION_ERROR_10004 = -10004
+STATUS_INITIALIZATION_ERROR_10005 = -10005
+STATUS_INITIALIZATION_ERROR_10006 = -10006
 
 CONNECTORTYPE_UNKNOWN = 0x00000000
 CONNECTORTYPE_BNC = 0x00000001
@@ -97,6 +104,17 @@ TRIGGERIO_INDEX_INVALID = 0xffff
 
 STRING_LENGTH_NULL_TERMINATED = 0xffffffff
 
+SERVER_STATUS_DISCONNECTED = 0
+SERVER_STATUS_CONNECTING = 1
+SERVER_STATUS_CONNECTED = 2
+SERVER_STATUS_DISCONNECTING = 3
+SERVER_ERROR_NONE = 0
+SERVER_ERROR_UNKNOWN = 1
+SERVER_ERROR_CONNECTIONREFUSED = 2
+SERVER_ERROR_NETWORKUNREACHABLE = 3
+SERVER_ERROR_TIMEDOUT = 4
+SERVER_ERROR_HOSTNAMELOOKUPFAILED = 5
+
 RANGEINDEX_AUTO = 0xffffffff
 
 POINTER_ARRAY_MAX_LENGTH = 256
@@ -343,7 +361,7 @@ TOID_EXT1 = ((DN_MAIN << TIOID_SHIFT_DN) | ((PGID_EXTERNAL_DSUB) << TIOID_SHIFT_
 TOID_EXT2 = ((DN_MAIN << TIOID_SHIFT_DN) | ((PGID_EXTERNAL_DSUB) << TIOID_SHIFT_PGID) | ((SGID_PIN2) << TIOID_SHIFT_SGID) | ((FID_EXT_TRIGGERED) << TIOID_SHIFT_FID))
 TOID_EXT3 = ((DN_MAIN << TIOID_SHIFT_DN) | ((PGID_EXTERNAL_DSUB) << TIOID_SHIFT_PGID) | ((SGID_PIN3) << TIOID_SHIFT_SGID) | ((FID_EXT_TRIGGERED) << TIOID_SHIFT_FID))
 
-TKN_COUNT = 13
+TKN_COUNT = 15
 
 TKB_RISINGEDGE = 0
 TKB_FALLINGEDGE = 1
@@ -358,6 +376,8 @@ TKB_PULSEWIDTHEITHER = 9
 TKB_RUNTPULSEPOSITIVE = 10
 TKB_RUNTPULSENEGATIVE = 11
 TKB_RUNTPULSEEITHER = 12
+TKB_INTERVALRISING = 13
+TKB_INTERVALFALLING = 14
 
 TK_UNKNOWN = 0
 TK_RISINGEDGE = (1 << TKB_RISINGEDGE)
@@ -373,6 +393,8 @@ TK_PULSEWIDTHEITHER = (1 << TKB_PULSEWIDTHEITHER)
 TK_RUNTPULSEPOSITIVE = (1 << TKB_RUNTPULSEPOSITIVE)
 TK_RUNTPULSENEGATIVE = (1 << TKB_RUNTPULSENEGATIVE)
 TK_RUNTPULSEEITHER = (1 << TKB_RUNTPULSEEITHER)
+TK_INTERVALRISING = (1 << TKB_INTERVALRISING)
+TK_INTERVALFALLING = (1 << TKB_INTERVALFALLING)
 
 TKM_NONE = 0
 TKM_EDGE = (TK_RISINGEDGE | TK_FALLINGEDGE | TK_ANYEDGE)
@@ -380,7 +402,8 @@ TKM_WINDOW = (TK_INWINDOW | TK_OUTWINDOW | TK_ENTERWINDOW | TK_EXITWINDOW)
 TKM_PULSEWIDTH = (TK_PULSEWIDTHPOSITIVE | TK_PULSEWIDTHNEGATIVE | TK_PULSEWIDTHEITHER)
 TKM_RUNTPULSE = (TK_RUNTPULSEPOSITIVE | TK_RUNTPULSENEGATIVE | TK_RUNTPULSEEITHER)
 TKM_PULSE = (TKM_PULSEWIDTH | TKM_RUNTPULSE)
-TKM_TIME = (TKM_PULSEWIDTH | TKM_WINDOW)
+TKM_INTERVAL = (TK_INTERVALRISING | TK_INTERVALFALLING)
+TKM_TIME = (TKM_PULSEWIDTH | TKM_WINDOW | TKM_INTERVAL)
 TKM_ALL = ((1 << TKN_COUNT) - 1)
 
 TLMN_COUNT = 2
@@ -430,6 +453,8 @@ PID_HS5 = 22
 PID_HS6D = 25
 PID_ATS610004D = 31
 PID_ATS605004D = 32
+PID_WS6 = 34
+PID_WS5 = 35
 
 EVENTID_INVALID = 0
 EVENTID_OBJ_REMOVED = 1
@@ -442,6 +467,7 @@ EVENTID_GEN_CONTROLLABLECHANGED = 7
 EVENTID_SRV_STATUSCHANGED = 8
 EVENTID_SCP_SAFEGROUNDERROR = 9
 EVENTID_SCP_GETDATAASYNCCOMPLETED = 10
+EVENTID_DEV_BATTERYSTATUSCHANGED = 11
 
 if platform.system() == 'Windows':
     WM_USER = 0x0400
@@ -449,6 +475,7 @@ if platform.system() == 'Windows':
     WM_LIBTIEPIE_LST_DEVICEADDED = (WM_LIBTIEPIE + 2)
     WM_LIBTIEPIE_LST_DEVICEREMOVED = (WM_LIBTIEPIE + 3)
     WM_LIBTIEPIE_LST_DEVICECANOPENCHANGED = (WM_LIBTIEPIE + 9)
+    WM_LIBTIEPIE_NETSRV_ADDED = (WM_LIBTIEPIE + 11)
     WM_LIBTIEPIE_DEV_REMOVED = (WM_LIBTIEPIE + 4)
     WM_LIBTIEPIE_SCP_DATAREADY = (WM_LIBTIEPIE + 0)
     WM_LIBTIEPIE_SCP_DATAOVERFLOW = (WM_LIBTIEPIE + 1)
@@ -532,6 +559,7 @@ INTERFACES = {
     INTERFACE_OSCILLOSCOPE: 'Oscilloscope',
     INTERFACE_GENERATOR: 'Generator',
     INTERFACE_I2CHOST: 'I2CHost',
+    INTERFACE_SERVER: 'Server',
 }
 
 MEASURE_MODES = {
@@ -540,6 +568,22 @@ MEASURE_MODES = {
     MM_BLOCK: 'Block',
 }
 
+SERVER_ERRORS = {
+    SERVER_ERROR_NONE: 'None',
+    SERVER_ERROR_UNKNOWN: 'Unknown',
+    SERVER_ERROR_CONNECTIONREFUSED: 'Connection refused',
+    SERVER_ERROR_NETWORKUNREACHABLE: 'Network unreachable',
+    SERVER_ERROR_TIMEDOUT: 'Timed out',
+    SERVER_ERROR_HOSTNAMELOOKUPFAILED: 'Hostname lookup failed',
+}
+
+SERVER_STATUSS = {
+    SERVER_STATUS_DISCONNECTED: 'Disconnected',
+    SERVER_STATUS_CONNECTING: 'Connecting',
+    SERVER_STATUS_CONNECTED: 'Connected',
+    SERVER_STATUS_DISCONNECTING: 'Disconnecting',
+}
+
 SIGNAL_TYPES = {
     ST_UNKNOWN: 'Unknown',
     ST_SINE: 'Sine',
@@ -575,6 +619,8 @@ TRIGGER_KINDS = {
     TK_RUNTPULSEPOSITIVE: 'Runt pulse positive',
     TK_RUNTPULSENEGATIVE: 'Runt pulse negative',
     TK_RUNTPULSEEITHER: 'Runt pulse either',
+    TK_INTERVALRISING: 'Interval rising',
+    TK_INTERVALFALLING: 'Interval falling',
 }
 
 TRIGGER_LEVEL_MODES = {
